===========
Haralyzer_3
===========
.. image:: https://github.com/Cyb3r-Jak3/haralyzer_3/workflows/Python%20Checking/badge.svg?branch=master
   :target: https://github.com/Cyb3r-Jak3/haralyzer_3/actions?query=branch%3Amaster+workflow%3A%22Python+Checking%22
   :alt: Build status


.. image:: https://codecov.io/gh/Cyb3r-Jak3/haralyzer_3/branch/master/graph/badge.svg?token=8YAOGCMLX4
    :target: https://codecov.io/gh/Cyb3r-Jak3/haralyzer_3
    :alt: Coverage status

.. image:: https://readthedocs.org/projects/haralyzer-3/badge/?version=latest
    :target: https://haralyzer-3.readthedocs.io/en/latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Python Black Code Style




.. image:: https://img.shields.io/pypi/v/haralyzer_3?style=flat-square
    :target: https://pypi.org/project/haralyzer_3/
    :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/haralyzer_3?style=flat-square
    :target: https://pypi.org/project/haralyzer_3/
    :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/dw/haralyzer_3
    :target: https://pypi.org/project/haralyzer_3/
    :alt: PyPI - Downloads

A Python 3 Framework For Using HAR Files To Analyze Web Pages.

This is a fork of https://github.com/mrname/haralyzer but only supports Python 3

To learn more about how to this this project, check out the `documentation <https://haralyzer-3.readthedocs.io/>`_.


Getting started
===============

Installing

.. code-block:: bash

    pip install haralyzer-3

Importing

.. code-block::

    import haralyzer_3

